@@ -1,4 +1,5 @@
 module FakeFS
+  # Fake symlink class
   class FakeSymlink
     attr_accessor :name, :target, :parent
 
@@ -7,7 +8,7 @@ module FakeFS
     end
 
     def inspect
-      "symlink(#{target.split('/').last})"
+      "symlink(#{name} -> #{target.split('/').last})"
     end
 
     def entry
@@ -22,11 +23,11 @@ module FakeFS
       File.join(parent.to_s, name)
     end
 
-    def respond_to?(method)
-      entry.respond_to?(method)
+    def respond_to?(method, include_private = false)
+      entry.respond_to?(method, include_private)
     end
 
-  private
+    private
 
     def method_missing(*args, &block)
       entry.send(*args, &block)
