@@ -1,14 +1,15 @@
 require 'stringio'
 
 module FakeFS
+  # FakeFS File class inherit StringIO
   class File < StringIO
     MODES = [
-      READ_ONLY           = "r",
-      READ_WRITE          = "r+",
-      WRITE_ONLY          = "w",
-      READ_WRITE_TRUNCATE = "w+",
-      APPEND_WRITE_ONLY   = "a",
-      APPEND_READ_WRITE   = "a+"
+      READ_ONLY           = 'r',
+      READ_WRITE          = 'r+',
+      WRITE_ONLY          = 'w',
+      READ_WRITE_TRUNCATE = 'w+',
+      APPEND_WRITE_ONLY   = 'a',
+      APPEND_READ_WRITE   = 'a+'
     ]
 
     FILE_CREATION_MODES = MODES - [READ_ONLY, READ_WRITE]
@@ -35,11 +36,11 @@ module FakeFS
     end
 
     def self.exist?(path)
-      if(File.symlink?(path)) then
+      if File.symlink?(path)
         referent = File.expand_path(File.readlink(path), File.dirname(path))
         exist?(referent)
       else
-        !!FileSystem.find(path)
+        !FileSystem.find(path).nil?
       end
     end
 
@@ -49,13 +50,18 @@ module FakeFS
       # Assuming that everyone can read and write files
       alias_method :readable?, :exist?
       alias_method :writable?, :exist?
+
+      # Assume nothing is sticky.
+      def sticky?(_path)
+        false
+      end
     end
 
     def self.mtime(path)
       if exists?(path)
         FileSystem.find(path).mtime
       else
-        raise Errno::ENOENT
+        fail Errno::ENOENT
       end
     end
 
@@ -63,7 +69,7 @@ module FakeFS
       if exists?(path)
         FileSystem.find(path).ctime
       else
-        raise Errno::ENOENT
+        fail Errno::ENOENT
       end
     end
 
@@ -71,7 +77,7 @@ module FakeFS
       if exists?(path)
         FileSystem.find(path).atime
       else
-        raise Errno::ENOENT
+        fail Errno::ENOENT
       end
     end
 
@@ -81,7 +87,7 @@ module FakeFS
           FileSystem.find(path).atime = atime
           FileSystem.find(path).mtime = mtime
         else
-          raise Errno::ENOENT
+          fail Errno::ENOENT
         end
       end
 
@@ -89,15 +95,15 @@ module FakeFS
     end
 
     def self.size(path)
-      read(path).length
+      read(path).bytesize
     end
 
     def self.size?(path)
-      if exists?(path) && !size(path).zero?
-        true
-      else
-        nil
-      end
+      size(path) if exists?(path) && !size(path).zero?
+    end
+
+    def self.zero?(path)
+      exists?(path) && size(path) == 0
     end
 
     def self.const_missing(name)
@@ -130,8 +136,8 @@ module FakeFS
       end
     end
 
-    def self.expand_path(*args)
-      RealFile.expand_path(*args)
+    def self.expand_path(file_name, dir_string = FileSystem.current_dir.to_s)
+      RealFile.expand_path(file_name, RealFile.expand_path(dir_string, Dir.pwd))
     end
 
     def self.basename(*args)
@@ -148,48 +154,52 @@ module FakeFS
     end
 
     def self.read(path, *args)
-      file = new(path)
-      if file.exists?
-        FileSystem.find(path).atime = Time.now
-        file.read
-      else
-        raise Errno::ENOENT
-      end
+      options = args[-1].is_a?(Hash) ? args.pop : {}
+      length = args.size > 0 ? args.shift : nil
+      offset = args.size > 0 ? args.shift : 0
+      file = new(path, options)
+
+      fail Errno::ENOENT unless file.exists?
+      fail Errno::EISDIR, path if directory?(path)
+
+      FileSystem.find(path).atime = Time.now
+      file.seek(offset)
+      file.read(length)
     end
 
     def self.readlines(path)
-      read(path).split("\n")
+      file = new(path)
+      if file.exists?
+        FileSystem.find(path).atime = Time.now
+        file.readlines
+      else
+        fail Errno::ENOENT
+      end
     end
 
     def self.rename(source, dest)
       if directory?(source) && file?(dest)
-        raise Errno::ENOTDIR, "Not a directory - #{source} or #{dest}"
+        fail Errno::ENOTDIR, "#{source} or #{dest}"
       elsif file?(source) && directory?(dest)
-        raise Errno::EISDIR, "Is a directory - #{source} or #{dest}"
+        fail Errno::EISDIR, "#{source} or #{dest}"
+      elsif !exist?(dirname(dest))
+        fail Errno::ENOENT, "#{source} or #{dest}"
       end
 
-      if target = FileSystem.find(source)
+      if (target = FileSystem.find(source))
         FileSystem.add(dest, target.entry.clone)
         FileSystem.delete(source)
       else
-        raise Errno::ENOENT,  "No such file or directory - #{source} or #{dest}"
+        fail Errno::ENOENT, "#{source} or #{dest}"
       end
 
       0
     end
 
     def self.link(source, dest)
-      if directory?(source)
-        raise Errno::EPERM, "Operation not permitted - #{source} or #{dest}"
-      end
-
-      if !exists?(source)
-        raise Errno::ENOENT, "No such file or directory - #{source} or #{dest}"
-      end
-
-      if exists?(dest)
-        raise Errno::EEXIST, "File exists - #{source} or #{dest}"
-      end
+      fail Errno::EPERM, "#{source} or #{dest}" if directory?(source)
+      fail Errno::ENOENT, "#{source} or #{dest}" unless exists?(source)
+      fail Errno::EEXIST, "#{source} or #{dest}" if exists?(dest)
 
       source = FileSystem.find(source)
       dest = FileSystem.add(dest, source.entry.clone)
@@ -198,18 +208,14 @@ module FakeFS
       0
     end
 
-    def self.delete(file_name, *additional_file_names)
-      if !exists?(file_name)
-        raise Errno::ENOENT, "No such file or directory - #{file_name}"
-      end
+    def self.delete(*file_names)
+      file_names.each do |file_name|
+        fail Errno::ENOENT, file_name unless exists?(file_name)
 
-      FileUtils.rm(file_name)
-
-      additional_file_names.each do |file_name|
         FileUtils.rm(file_name)
       end
 
-      additional_file_names.size + 1
+      file_names.size
     end
 
     class << self
@@ -229,46 +235,74 @@ module FakeFS
     end
 
     def self.split(path)
-      return RealFile.split(path)
+      RealFile.split(path)
     end
 
     def self.chmod(mode_int, filename)
       FileSystem.find(filename).mode = 0100000 + mode_int
     end
 
+    # Not exactly right, returns true if the file is chmod +x for owner. In the
+    # context of when you would use fakefs, this is usually what you want.
+    def self.executable?(filename)
+      file = FileSystem.find(filename)
+      return false unless file
+      (file.mode - 0100000) & 0100 != 0
+    end
+
     def self.chown(owner_int, group_int, filename)
       file = FileSystem.find(filename)
       if owner_int && owner_int != -1
-        owner_int.is_a?(Fixnum) or raise TypeError, "can't convert String into Integer"
+        owner_int.is_a?(Fixnum) || fail(TypeError,
+                                        "can't convert String into Integer")
         file.uid = owner_int
       end
       if group_int && group_int != -1
-        group_int.is_a?(Fixnum) or raise TypeError, "can't convert String into Integer"
+        group_int.is_a?(Fixnum) || fail(TypeError,
+                                        "can't convert String into Integer")
         file.gid = group_int
       end
     end
 
-    def self.umask
-      RealFile.umask
+    def self.umask(*args)
+      RealFile.umask(*args)
     end
 
+    def self.binread(file, length = nil, offset = 0)
+      File.read(file, length, offset, mode: 'rb:ASCII-8BIT')
+    end
+
+    def self.fnmatch?(pattern, path, flags = 0)
+      RealFile.fnmatch?(pattern, path, flags)
+    end
+
+    class << self
+      alias_method :fnmatch, :fnmatch?
+    end
+
+    # FakeFS Stat class
     class Stat
       attr_reader :ctime, :mtime, :atime, :mode, :uid, :gid
+      attr_reader :birthtime if RUBY_VERSION >= '2.2.0'
 
-      def initialize(file, __lstat = false)
-        if !File.exists?(file)
-          raise(Errno::ENOENT, "No such file or directory - #{file}")
-        end
+      def initialize(file, lstat = false)
+        fail(Errno::ENOENT, file) unless File.exist?(file)
 
         @file      = file
         @fake_file = FileSystem.find(@file)
-        @__lstat   = __lstat
+        @__lstat   = lstat
         @ctime     = @fake_file.ctime
         @mtime     = @fake_file.mtime
         @atime     = @fake_file.atime
         @mode      = @fake_file.mode
         @uid       = @fake_file.uid
         @gid       = @fake_file.gid
+        @birthtime =
+          if @fake_file.respond_to?(:birthtime)
+            @fake_file.birthtime
+          else
+            @fake_file.ctime
+          end
       end
 
       def symlink?
@@ -279,14 +313,40 @@ module FakeFS
         File.directory?(@file)
       end
 
-      # assumes, like above, that all files are readable and writable
+      def file?
+        File.file?(@file)
+      end
+
+      def ftype
+        return 'link' if symlink?
+        return 'directory' if directory?
+        'file'
+      end
+
+      # assumes, like above, that all files are readable and writable.
       def readable?
         true
       end
+
       def writable?
         true
       end
 
+      # Assume nothing is sticky.
+      def sticky?
+        false
+      end
+
+      # World_writable and readable are platform dependent
+      # usually comparing with S_IROTH defined on compilation (MRI)
+      def world_writable?
+        0777
+      end
+
+      def world_readable?
+        0777
+      end
+
       def nlink
         @fake_file.links.size
       end
@@ -312,7 +372,7 @@ module FakeFS
 
     attr_reader :path
 
-    def initialize(path, mode = READ_ONLY, perm = nil)
+    def initialize(path, mode = READ_ONLY, _perm = nil)
       @path = path
       @mode = mode.is_a?(Hash) ? (mode[:mode] || READ_ONLY) : mode
       @file = FileSystem.find(path)
@@ -351,12 +411,16 @@ module FakeFS
       undef_method :to_inputstream
     end
 
-    def ioctl(integer_cmd, arg)
-      raise NotImplementedError
+    def is_a?(klass)
+      RealFile.allocate.is_a?(klass)
     end
 
-    def read_nonblock(maxlen, outbuf = nil)
-      raise NotImplementedError
+    def ioctl(*)
+      fail NotImplementedError
+    end
+
+    def read_nonblock
+      fail NotImplementedError
     end
 
     def stat
@@ -378,12 +442,12 @@ module FakeFS
       self
     end
 
-    def write_nonblock(string)
-      raise NotImplementedError
+    def write_nonblock(*)
+      fail NotImplementedError
     end
 
-    def readpartial(maxlen, outbuf = nil)
-      raise NotImplementedError
+    def readpartial(*)
+      fail NotImplementedError
     end
 
     def atime
@@ -394,8 +458,8 @@ module FakeFS
       self.class.ctime(@path)
     end
 
-    def flock(locking_constant)
-      raise NotImplementedError
+    def flock(*)
+      fail NotImplementedError
     end
 
     def mtime
@@ -407,27 +471,32 @@ module FakeFS
     end
 
     def chown(owner_int, group_int)
-      if owner_int && owner_int != -1
-        owner_int.is_a?(Fixnum) or raise TypeError, "can't convert String into Integer"
-        @file.uid = owner_int
-      end
-      if group_int && group_int != -1
-        group_int.is_a?(Fixnum) or raise TypeError, "can't convert String into Integer"
-        @file.gid = group_int
-      end
+      return unless group_int && group_int != -1
+
+      owner_int.is_a?(Fixnum) || fail(
+        TypeError, "can't convert String into Integer")
+      @file.uid = owner_int
+
+      group_int.is_a?(Fixnum) || fail(
+        TypeError, "can't convert String into Integer")
+      @file.gid = group_int
     end
 
-    if RUBY_VERSION >= "1.9"
-      def binmode?
-        raise NotImplementedError
+    if RUBY_VERSION >= '1.9'
+      def self.realpath(*args)
+        RealFile.realpath(*args)
       end
 
-      def close_on_exec=(bool)
-        raise NotImplementedError
+      def binmode?
+        fail NotImplementedError
+      end
+
+      def close_on_exec=(_bool)
+        fail NotImplementedError
       end
 
       def close_on_exec?
-        raise NotImplementedError
+        fail NotImplementedError
       end
 
       def to_path
@@ -435,41 +504,99 @@ module FakeFS
       end
     end
 
-    if RUBY_VERSION >= "1.9.2"
-      attr_writer :autoclose
-
-      def autoclose?
-        @autoclose
+    if RUBY_VERSION >= '1.9.1'
+      def self.absolute_path(file_name, dir_name = Dir.getwd)
+        RealFile.absolute_path(file_name, dir_name)
       end
+    end
+
+    if RUBY_VERSION >= '1.9.2'
+      attr_accessor :autoclose
 
       def autoclose?
         @autoclose ? true : false
       end
 
-      def autoclose=(autoclose)
-        @autoclose = autoclose
-      end
-
       alias_method :fdatasync, :flush
 
       def size
         File.size(@path)
       end
-    end
 
-    if RUBY_VERSION >= "1.9.3"
-      def advise(advice, offset=0, len=0)
+      def self.realdirpath(*args)
+        RealFile.realdirpath(*args)
       end
     end
 
-  private
+    if RUBY_VERSION >= '1.9.3'
+      def advise(_advice, _offset = 0, _len = 0)
+      end
+
+      def self.write(filename, contents, offset = nil, open_args = {})
+        offset, open_args = nil, offset if offset.is_a?(Hash)
+        mode = offset ? 'a' : 'w'
+        if open_args.size > 0
+          if open_args[:open_args]
+            args = [filename, *open_args[:open_args]]
+          else
+            mode = open_args[:mode] || mode
+            args = [filename, mode, open_args]
+          end
+        else
+          args = [filename, mode]
+        end
+        if offset
+          open(*args) do |f|
+            f.seek(offset)
+            f.write(contents)
+          end
+        else
+          open(*args) do |f|
+            f << contents
+          end
+        end
+
+        contents.length
+      end
+    end
+
+    if RUBY_VERSION >= '2.2.0'
+      def self.birthtime(path)
+        if exists?(path)
+          FileSystem.find(path).birthtime
+        else
+          fail Errno::ENOENT
+        end
+      end
+
+      def birthtime
+        self.class.birthtime(@path)
+      end
+    end
+
+    def read(length = nil, buf = '')
+      read_buf = super(length, buf)
+      # change to binary only for ruby 1.9.3
+      if read_buf.respond_to?(:force_encoding) && binary_mode?
+        read_buf = read_buf.force_encoding('ASCII-8BIT')
+      end
+      read_buf
+    end
+
+    private
 
     def check_modes!
-      StringIO.new("", @mode)
+      StringIO.new('', @mode)
+    end
+
+    def binary_mode?
+      @mode.is_a?(String) && (@mode.include?('b') ||
+                              @mode.include?('binary')) &&
+        !@mode.include?('bom')
     end
 
     def check_file_existence!
-      raise Errno::ENOENT, @path unless @file
+      fail Errno::ENOENT, @path unless @file
     end
 
     def file_creation_mode?
@@ -477,7 +604,9 @@ module FakeFS
     end
 
     def mode_in?(list)
-      list.any? { |element| @mode.include?(element) } if @mode.respond_to?(:include?)
+      list.any? do |element|
+        @mode.include?(element)
+      end if @mode.respond_to?(:include?)
     end
 
     def mode_in_bitmask?(mask)
@@ -487,21 +616,18 @@ module FakeFS
     # Create a missing file if the path is valid.
     #
     def create_missing_file
-      raise Errno::EISDIR, "Is a directory - #{path}" if File.directory?(@path)
+      fail Errno::EISDIR, path if File.directory?(@path)
 
-      if !File.exists?(@path) # Unnecessary check, probably.
-        dirname = RealFile.dirname @path
+      return if File.exist?(@path) # Unnecessary check, probably.
+      dirname = RealFile.dirname @path
 
-        unless dirname == "."
-          dir = FileSystem.find dirname
+      unless dirname == '.'
+        dir = FileSystem.find dirname
 
-          unless dir.kind_of? FakeDir
-            raise Errno::ENOENT, "No such file or directory - #{path}"
-          end
-        end
-
-        @file = FileSystem.add(path, FakeFile.new)
+        fail Errno::ENOENT, path unless dir.is_a? FakeDir
       end
+
+      @file = FileSystem.add(path, FakeFile.new)
     end
   end
 end
