@@ -9,5 +9,5 @@ require 'fakefs/fileutils'
 require 'fakefs/file'
 require 'fakefs/file_test'
 require 'fakefs/dir'
-require 'fakefs/pathname' if RUBY_VERSION >= "1.9.3"
-
+require 'fakefs/pathname' if RUBY_VERSION >= '1.9.3'
+require 'fakefs/kernel'
