@@ -1,6 +1,7 @@
-require "test_helper"
+require 'test_helper'
 
-class FileJoin < Test::Unit::TestCase
+# File join test class
+class FileJoin < Minitest::Test
   def setup
     FakeFS.activate!
   end
@@ -10,10 +11,10 @@ class FileJoin < Test::Unit::TestCase
   end
 
   [
-    ["a", "b"],  ["a/", "b"], ["a", "/b"], ["a/", "/b"], ["a", "/", "b"]
+    %w(a b),  %w(a/ b), %w(a /b), %w(a/ /b), %w(a / b)
   ].each_with_index do |args, i|
     define_method "test_file_join_#{i}" do
       assert_equal RealFile.join(args), File.join(args)
     end
   end
-end
\ No newline at end of file
+end
